<%@ Page Language="C#" EnableViewState="false" Inherits="System.Web.UI.Page" %>

<%@ Import Namespace="ChooseYourStory.Stories" %>
<%@ Import Namespace="System.Linq" %>
<%@ Import Namespace="ChooseYourStory.Utilities" %>
<%@ Import Namespace="ChooseYourStory.WebApplication.Data" %>
<%@ Import Namespace="ChooseYourStory.WebApplication.Data.Mag" %>
<%@ Import Namespace="System.Collections.Generic" %>

<script runat="server">
	protected StoryState State;
	

	protected override void OnLoad(EventArgs e)
	{
		//is this a postback
		if (!Request.Form.HasKeys())
		{
			if (Request.QueryString["RestoreSave"] == "yes")
			{
				State = StoryState.CreateFromSave(User.Identity.Name, int.Parse(Request.QueryString["StoryId"]));
				State.NoAction();
			}
			else
			{
                var sid = int.Parse(Request.QueryString["StoryId"]);
                Tables.Games_Extended game = MagDataFactory
                    .ExecSql<ChooseYourStory.WebApplication.Data.Mag.Tables.Games_Extended>
                        ("SELECT * FROM [Games_Extended] WHERE [Game Id] = ?", sid).FirstOrDefault();
                if (!game.Date_Published.HasValue && game.AllowPreview_Indicator == "N"
                    && !User.IsInRole(ChooseYourStory.Security.CysRoles.Storygame_Moderator)
                    && game.Username != this.User.Identity.Name
                    && !MagDataFactory.ExecSql<Tables.Game_Coauthors>(
                            "SELECT * FROM [Game Coauthors] WHERE [Game Id] = ? " +
                            " AND [Username] = ? AND [Active Indicator]='Y'", 
                            sid, this.User.Identity.Name).Any())
                {
                    throw new InvalidOperationException("Storygame not found.");
                }
				State = StoryState.CreateFromStoryId(sid);
				ChooseYourStory.Legacy.LegacyLogger.PlayGame(State.StoryId);
			}
			return;
		}
		
		//must be, load storystate
		State = StoryState.CreateFromString(Request.Form["SS"]);
		
		//determine action
		switch (Request.Form["pbAction"])
		{
			case "FollowLink":
				{
					StoryStateReturnValues ret = State.FollowLink(int.Parse(Request.Form["pbValue"]));
					switch (ret)
					{
						case StoryStateReturnValues.EndStoryFollowed:
							Server.Transfer("rate.aspx", true);
							break;
						case StoryStateReturnValues.SaveStoryFollowed:
							Server.Transfer("save.aspx", true);
							break;							
					}
					break;
				}
			case "PickupItem":
				{
					int itemId = Convert.ToInt32(Request.Form["pbValue"]);
					State.PickUpItem(itemId);
					break;
				}
			case "UseItem":
				{
					int itemId = Convert.ToInt32(Request.Form["pbValue"]);
					StoryStateReturnValues retVal = State.UseItem(itemId);
					switch (retVal)
					{
						case StoryStateReturnValues.EndStoryFollowed:
							Server.Transfer("rate.aspx", true);
							break;
						case StoryStateReturnValues.SaveStoryFollowed:
							Server.Transfer("save.aspx", true);
							break;
						case StoryStateReturnValues.ItemCannotBeUsedHere:
							ClientScript.RegisterStartupScript(typeof(string), "UseItemAlert", "alert('The item cannot be used here.');", true);
							break;
					}					
					break;
				}
			case "DropItem":
				{
					int itemId = Convert.ToInt32(Request.Form["pbValue"]);
					State.DropItem(itemId);
					break;
				}
			case "Save":
				Server.Transfer("save.aspx", true);
				break;
			default:
				State.NoAction();
				break;
		}
		
	}
	protected override void OnLoadComplete(EventArgs e)
	{
		DataBind();
	}

	protected string getItemImageUrl(object imageId)
	{
		if (imageId == null) return "/i/object.gif";
		else return "/i/?" + imageId.ToString();
	}

	protected void ItemRepeater_ItemDataBound(object sender, RepeaterItemEventArgs e)
	{
		if (e.Item.ItemType == ListItemType.Item || e.Item.ItemType == ListItemType.AlternatingItem)
		{
			e.Item.Visible = !((StoryState.Item)e.Item.DataItem).UsedUp;
		}
		else if (e.Item.ItemType == ListItemType.Separator)
		{
			e.Item.Visible = e.Item.ItemIndex % 6 == 5;
		}
	}
</script>

<%@ Register Assembly="ChooseYourStory" Namespace="ChooseYourStory.Web.Controls"
	TagPrefix="cys" %>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head runat="server">
	<title runat="server">
		<%#State.StoryTitle%>
		:: Story Viewer</title>

	<script language="JavaScript1.2" type="text/javascript"><!--
		function getEl(item) {
			if( window.mmIsOpera ) return(document.getElementById(item));
			if (document.all) return(document.all[item]);
			if (document.getElementById) return(document.getElementById(item));
			return(false);
		}		
		
		function PostBack(action,value)
		{
			var frm = getEl('<%#pbForm.ClientID %>');
			frm.pbAction.value = action?action:'';
			frm.pbValue.value = value?value:'';
			frm.submit();
			return false;
		}
		
	//--></script>

	<script language="JavaScript1.2" type="text/javascript" src="mm_menu.js"></script>
    <style type="text/css">
        #svbanner { background-image: url(/App_Themes/CYS/images/storyviewer_masthead_background.gif); height:20px; opacity:.8; }
        #svbanner img { float: left; }
        #svbanner ul { margin:0 10px; padding: 0; float: right; }
        #svbanner ul li { margin:0; padding:0; display:inline;}
        #svbanner ul li a { text-transform:uppercase; font-size: 10px; font-family: Arial;
                            display: block; float:left; height:12px; line-height:12px; margin:4px 10px; padding: 0 2px;
                            background-color: #cc3333; color: #ffffdd; }

		.dark1border {
		  max-width: 715px;
		  min-width: 350px;
		  margin-left: auto !important;
		  margin-right: auto !important;
		}

		.dark1border + div {
		  margin: 0 auto !important;
		  max-width: 715px;
		  min-width: 350px;
		}

		@media (min-width: 1300px) {
		  .dark1border,
		  .dark1border + div {
			max-width: 55%;
		  }
		}
    </style>
</head>
<body>
	<!-- BEGIN BANNER -->	
    <div id="svbanner">
        <cys:ThemedImage runat="server" src="storyviewer_masthead_logo.gif" width="150" height="20" border="0" alt="ChooseYourStory.com" />
        <ul>
            <li><a href="javascript: history.go(-1)">Go Back</a></li>
            <li><a href="default.aspx?StoryId=<%#State.StoryId %>">Restart</a></li>
            <% if (State.AllowSaves) { %>
            <li><a href="javascript: PostBack('Save');">Save</a></li>
            <% } else { %>
            <li><a href="javascript: alert('The author has disabled player saves.\\nYou will have to find a save-game link somewhere in the game in order to save your progress.');">Save</a></li>
            <% } %>
            <li><a href="javascript: if (confirm('Are you sure you want to close this window and quit?')) window.close();">Quit</a></li>
        </ul>
    </div>	
	<!--  END BANNER -->
	
	<!--  BEGIN PAGE TITLE -->
	<div class="dark1border" style="text-align: center; margin: 20px 50px 20px 50px;
		padding: 0px 20px 0px 20px; border-top-width: 1px; border-bottom-width: 1px; border-top-style: solid;
		border-bottom-style: solid;">
		<h1 runat="server" id="_storyTitle"><%#State.CurrentPage.PageTitle%></h1>
	</div>
	<!-- END PAGE TITLE -->
	
	<!-- BEGIN MAIN -->
	<div style="padding:0px 30px 50px 30px">
		<div>
			<%#ChooseYourStory.WebApplication.Util.Formatting.SafeHtmlFormat(State.CurrentPage.PageText)%>
		</div>
		<div style="clear:both; margin-top:10px;">
			<asp:Repeater ID="Repeater1" runat="server" DataSource="<%#State.Variables.FindAllToDisplayOnPage() %>">
			<ItemTemplate>
				<%#Eval("Name") %> is <%#Eval("Value") %>.<br />
			</ItemTemplate>
			</asp:Repeater>		
		</div>
		
		<!-- Page Items -->
		<table cellspacing="10" cellpadding="0" border="0">
			<tr>
		<asp:Repeater runat="server" DataSource="<%#State.CurrentPage.Items %>">
			<ItemTemplate>
				<td class="smallerText" width="75" align="center" valign="top">
					<a href="#" onclick="PostBack('PickupItem','<%#Eval("ItemId")%>');return false;" >
						<asp:Image ID="Image1" runat="server" style="display:block " 
							ImageUrl='<%#getItemImageUrl(Eval("ImageId"))%>' Width="75"
							AlternateText='<%#Server.HtmlEncode((string)Eval("Description"))%>'
							/>
						<%#Server.HtmlEncode((string)Eval("Title"))%>
					</a>
				</td>
			</ItemTemplate>
		</asp:Repeater>
			</tr>
		</table>
		
		<!-- Links -->
		<div style="margin: 20px; padding: 4px; border-left: 1px solid #000033;" class="smallerText" runat="server" visible="<%#State.CurrentPage.Links.Count == 0 %>">
			<strong>No Links.</strong> 
			You may <a href="#" onclick="history.go(-1);return false;">go back</a><asp:PlaceHolder 
				runat="server" Visible="<%#State.InventoryItems.HasUsableItems() %>">, try to <i>use</i> one of your items,
			</asp:PlaceHolder>
			or <a href="#" onclick="location=window.location.href;return false;">reset</a> to start over.
		</div>
		
		<asp:Repeater runat="server" Visible="true" DataSource="<%# State.CurrentPage.Links %>">
			<HeaderTemplate>
				<ul>
			</HeaderTemplate>
			<ItemTemplate>
				<li runat="server" Visible='<%#(bool)Eval("Enabled") || (bool)Eval("VisibleWhenInactive") %>'>
					<asp:Literal runat="server" Text='<%#Eval("Title") %>'
						 Visible='<%#!(bool)Eval("Enabled") %>' />
					<asp:HyperLink runat="server" Text='<%#Eval("Title") %>' 
						NavigateUrl="#"
						onclick=<%# "PostBack('FollowLink','" + Eval("LinkId").ToString() + "');return false;" %>
						Visible='<%#(bool)Eval("Enabled") %>' />
				</li>
			</ItemTemplate>
			<FooterTemplate>
				</ul>
			</FooterTemplate>
		</asp:Repeater>
		
		<!-- Inventory -->
		<table border="0" cellspacing="0" cellpadding="0" runat="server" visible="<%#State.InventoryItems.HasUsableItems() %>">
			<tr>
				<td width="5"><img height="19" src="images/i_tl.gif" width="5" alt="" /></td>
				<td width="18"><img height="19" src="images/i_tbar.gif" width="18" alt="" /></td>
				<td width="5"><img height="19" src="images/i_ml.gif" width="5" alt="" /></td>
				<td align="center"><h2 align="center">&nbsp;&nbsp;My&nbsp;Inventory&nbsp;&nbsp;</h2></td>
				<td width="5"><img height="19" src="images/i_mr.gif" width="5" /></td>
				<td width="75%"><img height="19" src="images/i_tbar.gif" width="100%" alt="" /></td>
				<td width="5"><img height="19" src="images/i_tr.gif" width="5" /></td>
			</tr>
			<tr>
				<td style="background-image:url(images/i_m.gif); background-position:center; background-repeat:repeat-y;"><cys:SpacerImage runat="server" /></td>
				<td colspan="5">
					<!-- Item Preview -->
					<asp:Repeater runat="server" DataSource="<%#State.InventoryItems.FindAllNotUsedUp() %>" OnItemDataBound="ItemRepeater_ItemDataBound">
						<ItemTemplate>
							<table border="0" cellpadding="0" cellspacing="0" width="600" id="Item_<%#Eval("ItemId")%>" style="display: none;">
								<tr><td colspan="5"><cys:SpacerImage runat="server" Height="10" /></td></tr>
								<tr>
									<td valign="top"><cys:SpacerImage runat="server" Width="10" /></td>
									<td><img src="<%#getItemImageUrl(Eval("ImageId")) %>" /></td>
									<td valign="top"><cys:SpacerImage runat="server" Width="10" /></td>
									<td valign="top">
										<h2><%#Server.HtmlEncode((string)Eval("Title"))%></h2>
										<p><%#ChooseYourStory.WebApplication.Util.Formatting.SafeHtmlFormat((string)Eval("Description"))%></p>
										<p align="center">
											
											<asp:HyperLink runat="server" 
												NavigateUrl="#"
												onclick=<%# "PostBack('UseItem','" + Eval("ItemId").ToString() + "');return false;" %>
												Text="[Use&nbsp;Item]" />
											&nbsp;&nbsp;
											<a href="#" onclick="getEl('Item_<%#Eval("ItemId")%>').style.display='none';return false;">[Hide]</a>
											&nbsp;&nbsp;
											<asp:HyperLink runat="server"  Visible='<%#Eval("IsDroppable") %>'
												NavigateUrl="#"
												onclick=<%# "PostBack('DropItem','" + Eval("ItemId").ToString() + "');return false;" %>
												Text="[Drop&nbsp;Item]" />											
										</p>
									</td>
									<td valign="top"><cys:SpacerImage runat="server" Width="10" /></td>
								</tr>
								<tr>
									<td><cys:SpacerImage runat="server" Width="10" Height="5" /></td>
									<td colspan="3"><img height="19" src="images/i_tbar.gif" width="100%" alt="" /></td>
									<td><cys:SpacerImage runat="server" Width="10" Height="5" /></td>
								</tr>
							</table>
						</ItemTemplate>
					</asp:Repeater>
					<!-- Item Table -->
					<table cellpadding="0" cellspacing="10" border="0">
						<tr>
					<asp:Repeater runat="server" DataSource="<%#State.InventoryItems.FindAllNotUsedUp() %>" OnItemDataBound="ItemRepeater_ItemDataBound">
						<ItemTemplate>
							<td width="75" class="smallerText" align="center" valign="top">
								<a href="#" onclick="getEl('Item_<%#Eval("ItemId")%>').style.display='block';return false;">
									<img style="display: block;" src="<%#getItemImageUrl(Eval("ImageId")) %>" width="50" height="50" border="0" />
									<%#Server.HtmlEncode((string)Eval("Title")) %>
								</a>
							</td>
						</ItemTemplate>
						<SeparatorTemplate>
							</tr></tr>
						</SeparatorTemplate>
					</asp:Repeater>
						</tr>
					</table>
				</td>
				<td style="background-image:url(images/i_m.gif); background-position:center; background-repeat:repeat-y;"><cys:SpacerImage runat="server" /></td>
			</tr>
			<tr>
				<td><img height="5" src="images/i_bl.gif" width="5" /></td>
				<td colspan="5"><img height="5" src="images/i_bbar.gif" width="100%" alt="" /></td>
				<td><img height="5" src="images/i_br.gif" width="5" /></td>
			</tr>
		</table>
		
	</div>
	<!-- END MAIN -->
	<map name="m_navbar" id="m_navbar">
		<area shape="rect" coords="0,0,60,20" href="JavaScript: history.go(-1);" alt="" />
		<area shape="rect" coords="60,0,120,20" href="#" alt="" onmouseout="MM_startTimeout();"
			onmouseover="MM_showMenu(window.mm_root_menu,55,15,null,'navbar');" />
	</map>
		
	<form runat="server" method="post" id="pbForm">
		<input type="hidden" name="SS" value="<%#State.CreateStoryStateString()%>" />
		<input type="hidden" name="pbAction" value="" />
		<input type="hidden" name="pbValue" value="" />
	</form>
</body>
</html>
